@@ -1,5 +1,3 @@
-/* $Id: main.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -152,6 +150,15 @@ handle_parent_connection (int s)
 		       resp->u.data.proc_map.total, ptr);
 	    g_free (ptr);
 	    break;
+
+	case GLIBTOP_CMND_PROC_WD:
+		/* FIXME */
+	    break;
+
+	case GLIBTOP_CMND_NETLIST:
+		/* FIXME */
+	    break;
+
 	case GLIBTOP_CMND_PROC_ARGS:
 	    memcpy (&pid, parameter, sizeof (pid_t));
 	    ptr = glibtop_get_proc_args_l (server,
